PyJAGS: The Python Interface to JAGS
====================================

|docs| |build|

PyJAGS provides a Python interface to JAGS, a program for analysis of Bayesian
hierarchical models using Markov Chain Monte Carlo (MCMC) simulation.

License: GPLv2

Installation
------------

::

  pip install pyjags

Useful links
------------

* `Documentation hosted on the Read the Docs
  <https://pyjags.readthedocs.org/en/latest/?badge=latest>`_
* `Package on the Python Package Index <https://pypi.python.org/pypi/pyjags>`_
* `Project page on github <https://github.com/tmiasko/pyjags>`_
* `JAGS manual and examples <http://sourceforge.net/projects/mcmc-jags/files/>`_

.. |docs| image:: https://readthedocs.org/projects/pyjags/badge/?version=latest
    :alt: Documentation Status
    :target: https://pyjags.readthedocs.org/en/latest/?badge=latest
.. |build| image:: https://travis-ci.org/tmiasko/pyjags.svg?branch=travis
    :alt: Build Status
    :target: https://travis-ci.org/tmiasko/pyjags
